@@ -1,7 +1,7 @@
 """Python driver for Alicat mass flow controllers, using serial communication.
 
 Distributed under the GNU General Public License v2
-Copyright (C) 2015 NuMat Technologies
+Copyright (C) 2019 NuMat Technologies
 """
 try:
     import serial
@@ -66,9 +66,9 @@ class FlowMeter(object):
             try:
                 c = device.get()
                 if cls.__name__ == 'FlowMeter':
-                    assert c and 'flow_setpoint' not in device.keys
+                    assert c and 'setpoint' not in device.keys
                 elif cls.__name__ == 'FlowController':
-                    assert c and 'flow_setpoint' in device.keys
+                    assert c and 'setpoint' in device.keys
                 else:
                     raise NotImplementedError('Must be meter or controller.')
                 is_device = True
@@ -109,14 +109,14 @@ class FlowMeter(object):
         """
         self._test_controller_open()
 
-        command = '*@={addr}\r'.format(addr=self.address)
+        command = '{addr}\r'.format(addr=self.address)
         line = self._write_and_read(command, retries)
         spl = line.split()
         address, values = spl[0], spl[1:]
 
         # Mass/volume over range error.
         # Explicitly silenced because I find it redundant.
-        while values[-1] in ['MOV', 'VOV']:
+        while values[-1].upper() in ['MOV', 'VOV']:
             del values[-1]
 
         if address != self.address:
@@ -232,7 +232,10 @@ class FlowController(FlowMeter):
             address: The Alicat-specified address, A-Z. Default 'A'.
         """
         FlowMeter.__init__(self, port, address)
-        self.control_point = self._get_control_point()
+        try:
+            self.control_point = self._get_control_point()
+        except Exception:
+            self.control_point = None
 
     def get(self, retries=2):
         """Get the current state of the flow controller.
@@ -265,7 +268,7 @@ class FlowController(FlowMeter):
         Args:
             flow: The target flow rate, in units specified at time of purchase
         """
-        if self.control_point != 'flow':
+        if self.control_point is not None and self.control_point != 'flow':
             self._set_setpoint(0, retries)
             self._set_control_point('flow', retries)
         self._set_setpoint(flow, retries)
@@ -277,7 +280,7 @@ class FlowController(FlowMeter):
             pressure: The target pressure, in units specified at time of
                 purchase. Likely in psia.
         """
-        if self.control_point != 'pressure':
+        if self.control_point is not None and self.control_point != 'pressure':
             self._set_setpoint(0, retries)
             self._set_control_point('pressure', retries)
         self._set_setpoint(pressure, retries)
